==> haskell-time-locale-compat-0.1.1.4-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-locale-compat
version: 0.1.1.4
id: time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
key: time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
license: BSD-3-Clause
copyright: Copyright (c) 2014-2018 Kei Hibino
maintainer: ex8k.hibino@gmail.com
author: Kei Hibino
homepage: https://github.com/khibino/haskell-time-locale-compat
synopsis: Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.
category: System
abi: f41790414214237de89461384d016ee3
exposed: True
exposed-modules:
    Data.Time.Locale.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/time-locale-compat-0.1.1.4
hs-libraries: HStime-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
depends:
    base-4.11.1.0 time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock
haddock-html: /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-locale-compat-0.1.1.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-locale-compat
version: 0.1.1.5
id: time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
key: time-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
license: BSD-3-Clause
copyright: Copyright (c) 2014-2018 Kei Hibino
maintainer: ex8k.hibino@gmail.com
author: Kei Hibino
homepage: https://github.com/khibino/haskell-time-locale-compat
synopsis: Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.
category: System
abi: 0dc91a1ae9a857b8c5071d88d21ad3c6
exposed: True
exposed-modules:
    Data.Time.Locale.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/time-locale-compat-0.1.1.5
hs-libraries: HStime-locale-compat-0.1.1.5-DDznVvFVEsmlk0WqJppPg
depends:
    base-4.11.1.0 time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock
haddock-html: /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
